#ifndef S9X_VIDEO_H
#define S9X_VIDEO_H

#include "defines.h"
#include "frend.h"
#include "misc.h"
#include "skins.h"

class s9x_Video :       public s9x_Notepage
{
 private:
   fr_Checkbox		Scale, HiRes, FullScreen;
   fr_PulldownMenu	VideoSystem, TVmode;
   fr_Checkbox		UseFrameSkip, UseFrameTime, DisplayFrameRate;
   fr_NumEntry		FrameSkip, FrameTime;
   fr_Label		FrameSkipLabel, FrameTimeLabel;
   fr_MenuItem		*NTSC, *PAL;
   fr_MenuItem*         TVmodes[5];
   void			EventOccurred(fr_Event*e);
 public:
                        s9x_Video(fr_Notebook*parent);
   			~s9x_Video();
   void			SetToDefaults();
   void			Set9xVersion(float version);
   void			SiftArgs(fr_ArgList& L);
   void			CompileArgs(fr_ArgList& L);
};

#endif
